@@ -98,7 +98,7 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings_data()
     settings.sieveImapAccountSettings.setServerName(QStringLiteral("bla.foo.com"));
     settings.sieveImapAccountSettings.setPort(143);
     settings.sieveImapAccountSettings.setPassword(QStringLiteral("password_imap"));
-    settings.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::STARTTLS);
+    settings.sieveImapAccountSettings.setEncryptionMode(KSieveCore::SieveImapAccountSettings::EncryptionMode::STARTTLS);
 
     settings.sieveSettings.userName = QStringLiteral("foo@foo.com");
     settings.sieveSettings.serverName = QStringLiteral("bla.foo.com");
@@ -112,7 +112,7 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings_data()
     settings2.sieveImapAccountSettings.setServerName(QStringLiteral("bla.foo.com"));
     settings2.sieveImapAccountSettings.setPort(143);
     settings2.sieveImapAccountSettings.setPassword(QStringLiteral("password_imap"));
-    settings2.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::STARTTLS);
+    settings2.sieveImapAccountSettings.setEncryptionMode(KSieveCore::SieveImapAccountSettings::EncryptionMode::STARTTLS);
     settings2.sieveSettings.userName = QStringLiteral("b");
     settings2.sieveSettings.serverName = QStringLiteral("bla.foo.com"); // TODO
     settings2.sieveSettings.password = QStringLiteral("password_custom_sieve_imap");
@@ -124,8 +124,8 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings_data()
     settings3.sieveImapAccountSettings.setUserName(QStringLiteral("foo@foo.com"));
     settings3.sieveImapAccountSettings.setServerName(QStringLiteral("bla.foo.com"));
     settings3.sieveImapAccountSettings.setPort(143);
-    settings3.sieveImapAccountSettings.setAuthenticationType(static_cast<KSieveUi::SieveImapAccountSettings::AuthenticationMode>(3));
-    settings3.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::Unencrypted);
+    settings3.sieveImapAccountSettings.setAuthenticationType(static_cast<KSieveCore::SieveImapAccountSettings::AuthenticationMode>(3));
+    settings3.sieveImapAccountSettings.setEncryptionMode(KSieveCore::SieveImapAccountSettings::EncryptionMode::Unencrypted);
     settings3.sieveImapAccountSettings.setPassword(QStringLiteral("password_imap"));
     settings3.sieveSettings.userName = QStringLiteral("b");
     settings3.sieveSettings.password = QStringLiteral("password_custom_sieve_imap");
@@ -138,8 +138,8 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings_data()
     settings4.sieveImapAccountSettings.setUserName(QStringLiteral("foo@foo.com"));
     settings4.sieveImapAccountSettings.setServerName(QStringLiteral("bla.foo.com"));
     settings4.sieveImapAccountSettings.setPort(143);
-    settings4.sieveImapAccountSettings.setAuthenticationType(static_cast<KSieveUi::SieveImapAccountSettings::AuthenticationMode>(3));
-    settings4.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::STARTTLS);
+    settings4.sieveImapAccountSettings.setAuthenticationType(static_cast<KSieveCore::SieveImapAccountSettings::AuthenticationMode>(3));
+    settings4.sieveImapAccountSettings.setEncryptionMode(KSieveCore::SieveImapAccountSettings::EncryptionMode::STARTTLS);
     settings4.sieveImapAccountSettings.setPassword(QStringLiteral("password_imap"));
     settings4.sieveSettings.userName = QStringLiteral("b");
     settings4.sieveSettings.password = QStringLiteral("password_custom_sieve_imap");
@@ -152,8 +152,8 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings_data()
     settings5.sieveImapAccountSettings.setUserName(QStringLiteral("foo@foo.com"));
     settings5.sieveImapAccountSettings.setServerName(QStringLiteral("bla.foo.com"));
     settings5.sieveImapAccountSettings.setPort(143);
-    settings5.sieveImapAccountSettings.setAuthenticationType(static_cast<KSieveUi::SieveImapAccountSettings::AuthenticationMode>(3));
-    settings5.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::SSLorTLS);
+    settings5.sieveImapAccountSettings.setAuthenticationType(static_cast<KSieveCore::SieveImapAccountSettings::AuthenticationMode>(3));
+    settings5.sieveImapAccountSettings.setEncryptionMode(KSieveCore::SieveImapAccountSettings::EncryptionMode::SSLorTLS);
     settings5.sieveImapAccountSettings.setPassword(QStringLiteral("password_imap"));
     settings5.sieveSettings.userName = QStringLiteral("b");
     settings5.sieveSettings.serverName = QStringLiteral("bla.foo.com"); // TODO
@@ -181,3 +181,5 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings()
 }
 
 QTEST_MAIN(ImportImapSettingsAkonadiCheckJobTest)
+
+#include "moc_importimapsettingsakonadicheckjobtest.cpp"
