@@ -8,11 +8,7 @@
 
 #include "sieveeditorutil.h"
 #include <QObject>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
 #include <qt6keychain/keychain.h>
-#endif
 class ReadServerSieveConfigJob : public QObject
 {
     Q_OBJECT
@@ -22,7 +18,7 @@ public:
 
     void start();
 Q_SIGNALS:
-    void finished(const QVector<SieveEditorUtil::SieveServerConfig> &lstConfig);
+    void finished(const QList<SieveEditorUtil::SieveServerConfig> &lstConfig);
     void loadNextConfig();
 
 private:
@@ -31,7 +27,7 @@ private:
     void loadImapAccountSettings();
     void readSieveServerPasswordFinished(QKeychain::Job *baseJob);
     void readImapPasswordFinished(QKeychain::Job *baseJob);
-    QVector<SieveEditorUtil::SieveServerConfig> mLstConfig;
+    QList<SieveEditorUtil::SieveServerConfig> mLstConfig;
     SieveEditorUtil::SieveServerConfig mCurrentSieveServerConfig;
     QStringList mGroupsConfigs;
 };
