@@ -17,20 +17,20 @@ public:
     explicit ServerSieveSettingsDialog(QWidget *parent = nullptr);
     ~ServerSieveSettingsDialog() override;
 
-    Q_REQUIRED_RESULT QString serverName() const;
+    [[nodiscard]] QString serverName() const;
     void setServerName(const QString &name);
 
-    Q_REQUIRED_RESULT int port() const;
+    [[nodiscard]] int port() const;
     void setPort(int value);
 
-    Q_REQUIRED_RESULT QString userName() const;
+    [[nodiscard]] QString userName() const;
     void setUserName(const QString &name);
 
-    Q_REQUIRED_RESULT QString password() const;
+    [[nodiscard]] QString password() const;
     void setPassword(const QString &pass);
 
     void setServerSieveConfig(const SieveEditorUtil::SieveServerConfig &conf);
-    Q_REQUIRED_RESULT SieveEditorUtil::SieveServerConfig serverSieveConfig() const;
+    [[nodiscard]] SieveEditorUtil::SieveServerConfig serverSieveConfig() const;
 
 private:
     void slotEnableButtonOk(bool);
