@@ -40,8 +40,8 @@
 #include <QToolButton>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#include <KUserFeedbackQt6/NotificationPopup>
-#include <KUserFeedbackQt6/Provider>
+#include <KUserFeedback/NotificationPopup>
+#include <KUserFeedback/Provider>
 #endif
 
 #include <KWindowConfig>
