@@ -17,11 +17,7 @@
 #include <QRegularExpression>
 #include <QUrlQuery>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
 #include <qt6keychain/keychain.h>
-#endif
 using namespace QKeychain;
 
 QUrl SieveEditorUtil::SieveServerConfig::url() const
@@ -77,7 +73,7 @@ bool SieveEditorUtil::SieveServerConfig::operator==(const SieveEditorUtil::Sieve
     return result;
 }
 
-void SieveEditorUtil::writeServerSieveConfig(const QVector<SieveServerConfig> &lstConfig)
+void SieveEditorUtil::writeServerSieveConfig(const QList<SieveServerConfig> &lstConfig)
 {
     KSharedConfigPtr cfg = KSharedConfig::openConfig();
     const QRegularExpression re(QStringLiteral("^ServerSieve (.+)$"));
